Tool class final
Un outil que le modèle peut demander d'exécuter.
Constructors
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
parameters
→ Map<
String, dynamic> -
Schéma JSON des paramètres (manuel — pas de réflexion runtime en Flutter).
final
-
run
→ Future<
String> Function(Map<String, dynamic> args) -
Fonction réellement exécutée quand le modèle appelle l'outil.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited